@@ -404,11 +404,11 @@ impl EncodeMetric for Box<dyn EncodeMetric> {
     }
 }
 
-pub trait SendEncodeMetric: EncodeMetric + Send {}
+pub trait SendSyncEncodeMetric: EncodeMetric + Send + Sync {}
 
-impl<T: EncodeMetric + Send> SendEncodeMetric for T {}
+impl<T: EncodeMetric + Send + Sync> SendSyncEncodeMetric for T {}
 
-impl EncodeMetric for Box<dyn SendEncodeMetric> {
+impl EncodeMetric for Box<dyn SendSyncEncodeMetric> {
     fn encode(&self, encoder: Encoder) -> Result<(), std::io::Error> {
         self.deref().encode(encoder)
     }
@@ -571,7 +571,7 @@ fn encode_histogram_with_maybe_exemplars<S: Encode>(
         let mut value_encoder = bucket_encoder.encode_bucket(*upper_bound)?;
         let mut exemplar_encoder = value_encoder.encode_value(cummulative)?;
 
-        match exemplars.map(|es| es.get(&i)).flatten() {
+        match exemplars.and_then(|es| es.get(&i)) {
             Some(exemplar) => exemplar_encoder.encode_exemplar(exemplar)?,
             None => exemplar_encoder.no_exemplar()?,
         }
